@@ -1,4 +1,4 @@
-def _log_msg(name: str, size: int) -> str:
+def _log_msg(name: str, size: int) -> str:  # pragma: no cover
     """Return log message for creation of file.
 
     Args:
