@@ -13,10 +13,14 @@ def apply_curve(image: np.ndarray, f: Callable, c: int = -1) -> np.ndarray:
     Returns:
         np.ndarray: Image with curve applied.
     """
+    image = np.copy(image)
     if c == -1:
-        return f(image)
+        if len(image.shape) == 2:
+            return f(image)
+        else:
+            image[:,:,:3] = f(image[:,:,:3])
+            return image
     else:
-        image = np.copy(image)
         n,m,k = image.shape
         channels = np.reshape(image, (n*m,k))
         channels[:,c] = f(channels[:,c])
