@@ -1,7 +1,7 @@
 import numpy as np
 from math import floor, ceil, sqrt
 from functools import partial
-from typing import Callable
+from typing import List, Callable
 
 
 def _box_weighting_function(x: float) -> float:
@@ -81,6 +81,50 @@ RESIZE_FILTERS = \
      'catrom':   (_catmull_rom_weighting_function,  2.0),
      'gaussian': (_gaussian_weighting_function,     2.0)}
 
+
+def _safe_divide(n: np.ndarray, d: np.ndarray) -> np.ndarray:
+    """Divide NumPy arrays where divide by zero is zero.
+
+    Args:
+        n (np.ndarray): Numerator NumPy array.
+        d (np.ndarray): Denominator NumPy array.
+
+    Returns:
+        np.ndarray: Numerator divided by denominator.
+    """
+    return np.divide(n, d, out=np.zeros_like(n), where=(d != 0))
+
+
+def _over_alpha_composite(aA, aB) -> np.ndarray:
+    return aA + aB * (1 - aA)
+
+
+def _over_color_composite(xA, aA, xB, aB, xaA, xaB, aR) -> np.ndarray:
+    return _safe_divide(xaA + xaB * (1 - aA), aR)
+
+
+def _dest_over_alpha_composite(aA, aB) -> np.ndarray:
+    return aB + aA * (1 - aB)
+
+
+def _dest_over_color_composite(xA, aA, xB, aB, xaA, xaB, aR) -> np.ndarray:
+    return _safe_divide(xaB + xaA * (1 - aB), aR)
+
+
+def _add_alpha_composite(aA, aB) -> np.ndarray:
+    return np.clip(aA + aB, 0, 1)
+
+
+def _add_color_composite(xA, aA, xB, aB, xaA, xaB, aR) -> np.ndarray:
+    return _safe_divide(xaA + xaB, aR)
+
+
+COMPOSITE_OPERATORS = \
+    {'over':      (_over_alpha_composite, _over_color_composite),
+     'dest_over': (_dest_over_alpha_composite, _dest_over_color_composite),
+     'add':       (_add_alpha_composite, _add_color_composite)}
+
+
 EPSILON = 1.0e-6
 
 
@@ -226,6 +270,131 @@ def blur(image: np.ndarray, sigma: float, radius: float = 0) -> np.ndarray:
     return rescale(image, k=1, weighting_function=f, support=radius)
 
 
+def composite(source: np.ndarray,
+              dest: np.ndarray,
+              operator: str = 'over',
+              alpha_composite_function: Callable = None,
+              color_composite_function: Callable = None) -> np.ndarray:
+    """Return the image formed by compositing one image with another.
+
+    For more information about alpha compositing, see `Alpha Compositing`_.
+    The following compositing operators are built-in:
+
+    -  ("over"): two semi-transparent slides; source over dest.
+    -  ("dest_over"): two semi-transparent slides; dest over source.
+    -  ("add"): Add source and dest.
+
+    The built-in operators use the `Cairo Compositing Operators`_.
+
+    .. _Alpha Compositing: https://en.wikipedia.org/wiki/Alpha_compositing
+    .. _Cairo Compositing Operators: https://www.cairographics.org/operators
+
+    Args:
+        source (np.ndarray): Image on top.
+        dest (np.ndarray): Image on bottom.
+        operator (str): The compositing operator to use {over, dest_over, add}
+        alpha_composite_function (Callable): Alpha composite function to use.
+        color_composite_function (Callable): Color composite function to use.
+
+    Returns:
+        np.ndarray: The two images overlaid.
+    """
+    xA, aA = np.split(source, [3], axis=2)
+    xB, aB = np.split(dest, [3], axis=2)
+    xaA = xA * aA
+    xaB = xB * aB
+
+    if alpha_composite_function is not None:
+        if color_composite_function is None:
+            error_msg = "Alpha composite provided without color composite."
+            raise ValueError(error_msg)
+        alpha_composite = alpha_composite_function
+        color_composite = color_composite_function
+    else:
+        alpha_composite, color_composite = COMPOSITE_OPERATORS[operator]
+
+    aR = alpha_composite(aA, aB)
+    xR = color_composite(xA, aA, xB, aB, xaA, xaB, aR)
+    return np.append(xR, aR, axis=2)
+
+
+def _standardize_selection(image: np.ndarray, x: float, y: float, w: float,
+                           h: float, relative: bool, loc: str) -> List[float]:
+    if relative:
+        n,m,*_ = image.shape
+        x = m * x
+        y = n * y
+        w = m * w
+        h = n * h
+    if loc == "upper-left":
+        y = image.shape[0] - y
+    elif loc == "lower-left":
+        pass
+    elif loc == "center":
+        x = x - (w / 2)
+        y = y - (h / 2)
+    else:
+        raise ValueError(f"{loc} is not a supported loc.")
+    return int(x), int(y), int(w), int(h)
+
+
+def substitute(image: np.ndarray, substitution: np.ndarray, x: float, y: float,
+               relative: bool = False, loc: str = 'upper-left') -> np.ndarray:
+    """Substitute a portion of image with substitution.
+
+    Args:
+        image (np.ndarray): Base image.
+        substitution (np.ndarray): Image to substitute into the base image.
+        x (float): x coordinate of the point (relative to left of image).
+        y (float): y coordinate of the point (relative to bottom of image).
+        relative (bool): If True, x, y, w, and h are given relative to the \
+            dimensions of the image. Defaults to False.
+        loc (str): Location of (x,y) relative to substituted portion: \
+            {upper-left, lower-left, center}.
+
+    Returns:
+        np.ndarray: The image with substitution substituted in.
+    """
+    if relative:
+        n,m,*_ = image.shape
+        h,w,*_ = substitution.shape
+        w = w / m
+        h = h / n
+    else:
+        h,w,*_ = substitution.shape
+    x, y, w, h = _standardize_selection(image, x, y, w, h, relative, loc)
+    if len(image.shape) == 3:
+        image[y:y+h, x:x+w, :] = substitution
+    else:
+        image[y:y+h, x:x+w] = substitution
+    return image
+
+
+def crop(image: np.ndarray, x: float, y: float, w: float, h: float,
+         relative: bool = False, loc: str = 'upper-left') -> np.ndarray:
+    """Crop an image using an (x,y) point, width, and height.
+
+    Args:
+        image (np.ndarray): Image to be cropped.
+        x (float): x coordinate of the point (relative to left of image).
+        y (float): y coordinate of the point (relative to bottom of image).
+        w (float): Width of the cropped portion.
+        h (float): Height of the cropped portion.
+        relative (bool): If True, x, y, w, and h are given relative to the \
+            dimensions of the image. Defaults to False.
+        loc (str): Location of (x,y) relative to cropped portion: \
+            {upper-left, lower-left, center}.
+
+    Returns:
+        np.ndarray: The cropped portion of the image.
+    """
+    x, y, w, h = _standardize_selection(image, x, y, w, h, relative, loc)
+    if len(image.shape) == 3:
+        return image[y:y+h, x:x+w, :]
+    else:
+        return image[y:y+h, x:x+w]
+
+
 def clip(image: np.ndarray) -> np.ndarray:
     """Clip gray/color values that are out of bounds.
 
